function [fit_res, stats] = gen_psd_plots()
%GEN_PSD_PLOTS

% define some colors for plotting
new_color = [5 178 65]/255;
old_color = [169 83 255]/255;
match_color = [0 0 0]/255;

do_stats = false;

load('psd_dat','psd_dat');

do_stats = false;
if do_stats
    for c = 1:6
        for e = 1:size(psd_dat6,1)
            [fit_res(c,e).spectra, fit_res(c,e).stats, fit_res(c,e).peak_params, fit_res(c,e).ap_params] = fit_ps(freqs(freqs < 50 & freqs>0), ...
                squeeze(log10(psd_dat(c,e,(freqs < 50 & freqs>0)))));
        end
    end
else
    fit_res = [];
end

% group means, stderr
m1 = nanmean(psd_dat1); e1 = nanstd(psd_dat1)/sqrt(size(psd_dat1,1));
m2 = nanmean(psd_dat2); e2 = nanstd(psd_dat2)/sqrt(size(psd_dat2,1));
m3 = nanmean(psd_dat3); e3 = nanstd(psd_dat3)/sqrt(size(psd_dat3,1));

m4 = nanmean(psd_dat4); e4 = nanstd(psd_dat4)/sqrt(size(psd_dat4,1));
m5 = nanmean(psd_dat5); e5 = nanstd(psd_dat5)/sqrt(size(psd_dat5,1));
m6 = nanmean(psd_dat6); e6 = nanstd(psd_dat6)/sqrt(size(psd_dat6,1));


% generate plots
fig('FontSize', 16, ...
    'Font', 'Arial', ...
    'border','on', ...
    'units', 'centimeters', ...
    'width', 16, ...
    'height', 8);

ax1 = subplot(1,2,1);

% grid minor
title('Pre Fixation Onset');

f_idx = freqs>0 & freqs < 50;

% condition
[l, p] = boundedline(freqs(f_idx), m1(f_idx), e1(f_idx), ...
    freqs(f_idx), m2(f_idx), e2(f_idx), ...
    freqs(f_idx), m3(f_idx), e3(f_idx), ...
    'cmap', [old_color; new_color; match_color]);


for k = 1:length(l)
    set(l(k),'LineWidth',2);
    set(p(k),'FaceAlpha',.6);
end

set(gca,'YScale','log','box','off','XLim',[1 50], ...
    'Xscale','log','XTick',[1 2.5 5 10 25 50]);

set(gca,'YLim', [10^-1 10^4], ...
    'xgrid', 'on', ...
    'ygrid', 'on', ...
    'xminorgrid', 'off', ...
    'yminorgrid', 'on');

xlabel('Frequency (Hz)');
ylabel('Power (\muV^2/Hz)');

ax2 = subplot(1,2,2);

title('Post Fixation Onset');

% condition

[l, p] = boundedline(freqs(f_idx), m4(f_idx), e4(f_idx), ...
    freqs(f_idx), m5(f_idx), e5(f_idx), ...
    freqs(f_idx), m6(f_idx), e6(f_idx), ...
    'cmap', [old_color; new_color; match_color]);

for k = 1:length(l)
    set(l(k),'LineWidth',2);
    set(p(k),'FaceAlpha',.6);
end

set(gca,'YScale','log','box','off','XLim',[1 50], ...
    'Xscale','log','XTick',[1 2.5 5 10 25 50]);
xlabel('Frequency (Hz)');
ylabel('Power (\muV^2/Hz)');

linkaxes([ax1, ax2], 'xy');

set(gca,'YLim', [10^-1 10^4], ...
    'xgrid', 'on', ...
    'ygrid', 'on', ...
    'xminorgrid', 'off', ...
    'yminorgrid', 'on', ...
    'XTick', [1 2.5 5 10 25 50]);

hleg = legend(l, {'Original','Updated','Repeated'});
hleg.Location = 'SouthWest';
hleg.Box = 'Off';

% set(gcf,'Position',[18.5561    5.4681   21.8722   10.0189]);

end

function [psd_out, stats] = concat_psd(psd, do_stats)

% fit spectra for each event, to test for significance of peaks, within
% this condition

psd_out = [];
for s = 1:length(psd) % subjects
    
    n_hc = sum(psd(s).h_idx);
    ps = nan(n_hc, size(psd(s).psd,2), 102);
    ap = ps;
    
    e_cnt=1;
    for c = 1:size(psd(s).psd,1) % channels
        if psd(s).h_idx(c)
            for e = 1:size(psd(s).psd,2) % events
                
                freqs = psd(s).freqs;
                dat = squeeze(log10(psd(s).psd(c,e,(freqs < 50 & freqs>0))));
                
                if any(isinf(dat))
                    continue
                end
                
                if do_stats
                    spectra = fit_ps(freqs(freqs < 50 & freqs>0), ...
                        dat);
                    
                    ps(e_cnt,e,:) = spectra.ps_fit;
                    ap(e_cnt,e,:) = spectra.ap_fit;
                end
            end
            e_cnt = e_cnt+1;
        end
    end
    
    % and now test (could also just return this as output, which would
    % enable across condition testing
    if do_stats
        stats(s) = vartest_perm(ap, ps, freqs);
    else
        stats = [];
    end
    for c = 1:size(psd(s).psd,1) % channels
        if psd(s).h_idx(c)
            freqs = psd(s).freqs;
            psd_out = cat(1, psd_out, nanmean(squeeze(psd(s).psd(c,:,:))));
        end
    end
end

end

function stats = vartest_perm(ap, ps, freqs)
% nonparametric test comparing aperiodic fit to modeled ps with f-test (test
% of unequal variance as test statistic

ap = permute(ap, [2 1 3]);
ps = permute(ps, [2 1 3]);

cond1.powspctrm = ps;
cond1.dimord = 'rpt_chan_freq_time';
cond1.time   = 1;
cond1.freq   = freqs(freqs>0 & freqs < 50)';
for e = 1:size(ps, 2)
    cond1.label(e)  = {['c' num2str(e)]};
end

cond2.powspctrm = ap;
cond2.dimord = 'rpt_chan_freq_time';
cond2.time   = 1;
cond2.freq   = freqs(freqs>0 & freqs < 50)';

for e = 1:size(ap, 2)
    cond2.label(e)  = {['c' num2str(e)]};
end


correctm = 'cluster'; % cluster correction by default
numrandomization = 10000;
method = 'montecarlo';

cfg                  = [];
cfg.latency          = 'all';
cfg.parameter        = 'powspctrm';
cfg.method           = method;
cfg.statistic        = 'ft_statfun_vartest2';
cfg.channel          = 'all';
cfg.ivar             = 1;
cfg.frequency        = 'all';
cfg.design           = [ones(1,size(cond1.powspctrm,1)), ...
    ones(1,size(cond2.powspctrm,1))*2];
cfg.numrandomization = numrandomization;
cfg.alpha            = 0.05;

cfg.correctm         = correctm;
cfg.neighbours       = [];%neighbours;
cfg.clusterthreshold = 'nonparametric_individual';
cfg.correcttail      = 'none';
cfg.clusteralpha     = 0.05;
cfg.clusterstatistic = 'maxsum';

stats = ft_freqstatistics(cfg, cond1, cond2);


end